=======
Granola
=======

This is a "I feel like granola right now" recipe that makes a decent
granola without much fuss.

Tools:

1. non-stick 10" frying pan
2. rubber spatula


Ingredients:

1. 4 tablespoons of a fat (olive oil, butter, coconut oil, ...)

   These all have different flavors. Any of them will do. I like coconut oil
   since it gives a light coconut taste and coconut oil is pretty good for you
   as a fat.

2. 4 teaspoons of a sweetener (maple syrup, agave nectar, honey, ...)

   Any of these would do. You might be able to use a solid sweetener like brown
   sugar. Molasses might be interesting.

   I live in Massachusetts, USA so maple syrup is easy to acquire and it gives
   it a darker flavor that I like.

3. 1 cup of rolled oats

   It could be cut oats or whatever. The styling doesn't matter so much.
   
4. 1/2 cup of something something

   I like putting in hemp hearts and cashews that I break up while watching the
   oats brown. I also put in some cut dates. Other nice things: sesame seeds,
   sunflower seeds, chia seeds, shredded coconut, almond pieces, ...


Instructions:

1. Put the **frying pan** on the burner and turn it on high.

2. Put the **fat** and the **sweetener** in the pan, let them melt and combine.
   I move it around a bit with the **spatula** so it doesn't burn.

   This takes about a minute.

3. Dump the **oats** in and mix it all up so that the oats absorb the fat and
   sweetener.

   Then try to flatten out the oats so they can brown evenly.

   This takes about a minute.

4. Turn the burner down low and let the oats brown evenly. Stir periodically.

   Takes about eight to ten minutes depending. They should be noticeably
   browner, but don't burn them.

5. When they're brown, then dump them out on a cookie sheet, spread them out
   and let them cool.

   It's a small amount and the cookie sheet will dissipate the heat, so this
   takes

6. Dump the mixture and the **something something** into a bowl and stir it up.

7. Done!
